package com.sky.common.interceptor;

import com.sky.common.constant.JwtClaimsConstant;
import com.sky.common.context.BaseContext;
import com.sky.common.properties.RedisTokenProperties;
import com.sky.common.utils.JwtUtil;
import io.jsonwebtoken.Claims;
import lombok.extern.slf4j.Slf4j;
import org.apache.http.HttpStatus;
import org.checkerframework.checker.nullness.qual.NonNull;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Component;
import org.springframework.web.method.HandlerMethod;
import org.springframework.web.servlet.HandlerInterceptor;

import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpServletResponse;

@Component
@Slf4j
public class JwtTokenUserInterceptor implements HandlerInterceptor {
    @Autowired
    RedisTokenProperties redisTokenProperties;

    public boolean preHandle(@NonNull HttpServletRequest request, @NonNull HttpServletResponse response, @NonNull Object handler) throws Exception {
        // 判断当前拦截到的是Controller方法还是其它资源
        if (!(handler instanceof HandlerMethod)) {
            // 当前拦截到的不是动态方法，直接放行
            return true;
        }
        // 1. 从请求头中获取令牌
        String token = request.getHeader(redisTokenProperties.getUserTokenName());
        // 2. 校验令牌
        log.info("jwt校验：{}", token);
        try {
            Claims claims = JwtUtil.parseJWT(redisTokenProperties.getUserSecretKey(), token);
            Long userId = Long.valueOf(claims.get(JwtClaimsConstant.USER_ID).toString());
            BaseContext.setUserId(userId);
            return true;
        } catch (Exception exception) {
            response.setStatus(HttpStatus.SC_UNAUTHORIZED);
            return false;
        }
    }
}
